const sketch = require('sketch');

function connectMirror(context) {
  let mirror;
  try {
    mirror = NSApp.delegate().mirrorController();
  } catch (e) {}

  if (!mirror) {
    sketch.UI.message('Unexpected error happened (Error 101)');
    return;
  }

  let url;
  if ( mirror.whitelistClientAdvertisementID ) {
    const clientId = NSUUID.alloc().init();
    const webUrl = mirror.webURL();
    mirror.whitelistClientAdvertisementID(clientId);
    url = webUrl.absoluteString() + '?uuid=' + clientId;
  } else {
    url = mirror.authorizedWebURL().absoluteString();
  }

  if (!url) {
    sketch.UI.message('Unexpected error happened (Error 105)');
    return;
  }

  url = NSString.stringWithFormat('%@', url);
  const query = 'url=' + url.stringByAddingPercentEncodingWithAllowedCharacters(NSCharacterSet.URLPathAllowedCharacterSet());

  const components = NSURLComponents.new();
  components.setScheme('mockuuups');
  components.setHost('sketch');
  components.setQuery(query);

  const sharedWorkspace = NSWorkspace.sharedWorkspace();
  const openAppUrl = components.URL();
  const hasFoundApp = !!sharedWorkspace.URLForApplicationToOpenURL(openAppUrl);
  if (hasFoundApp) {
    sharedWorkspace.openURL(openAppUrl);
    sketch.UI.message('Opening this document in Mockuuups Studio…');
  } else {
    sketch.UI.alert('Mockuuups Studio wasn\'t found', 'This plugin connects Sketch artboards seamlessly to our mockup generator app.\n\nPlease download and install our Mac app and run the plugin again.');
    sharedWorkspace.openURL(NSURL.URLWithString('https://mockuuups.studio/download/'));
  }
}
connectMirror()
